============
Installation
============

At the command line::

    $ easy_install django-watchman

Or, if you have virtualenvwrapper installed::

    $ mkvirtualenv django-watchman
    $ pip install django-watchman